Crate dusk_vm

Crate dusk_vm 

[doc = include_str!(“../README.md”)]

Modules

host_queries
The host-queries registered on the Dusk VM

Structs

CallReceipt
The receipt given for a call execution using one of either call or call_raw. This receipt is also returned within a tuple when a Contract is deployed and its init method is executed.
CallTree
A cursor-based tree structure for tracking hierarchical contract calls.
CallTreeElem
An element of the call tree, representing a single contract call.
ContractData
ContractMetadata
Contract Metadata
ExecutionConfig
Configuration for the execution of a transaction.
PageOpening
A Merkle opening for page in the state.
Session
A running mutation to a state.
VM
The Virtual Machine (VM) for executing smart contracts in the Dusk Network.

Enums

Error
The error type returned by the piecrust VM.
ExecutionError
Errors that can occur during transaction execution in the VM.
FeatureActivation
Represents the activation condition for a feature or host query.

Functions

execute
Executes a transaction in the provided session.
gen_contract_id
Generates the canonical identifier of a contract deployment.