pub enum FeatureActivation {
Height(u64),
Ranges(Vec<(u64, u64)>),
}Expand description
Represents the activation condition for a feature or host query.
This enum defines when a specific feature or host query becomes active based on block heights. It can either be activated at a specific height or within specified ranges of block heights.
Variants
Height(u64)
Activation at a specific block height.
Ranges(Vec<(u64, u64)>)
Activation within specified ranges (including the lower and upper bound) of block heights.
Implementations
Sourceimpl Activation
impl Activation
Sourcepub fn is_active_at(&self, height: u64) -> bool
pub fn is_active_at(&self, height: u64) -> bool
Checks if the feature is active at the given block height.
Sourcepub fn unwrap_height(&self) -> u64
pub fn unwrap_height(&self) -> u64
Unwraps the activation height.
Panics if the activation is of type Activation::Ranges.
Sourcepub fn unwrap_ranges(&self) -> &[(u64, u64)]
pub fn unwrap_ranges(&self) -> &[(u64, u64)]
Unwraps the activation ranges.
Panics if the activation is of type Activation::Height.