pub struct ExecutionConfig {Show 15 fields
pub gas_per_deploy_byte: u64,
pub gas_per_blob: u64,
pub min_deploy_points: u64,
pub min_deploy_gas_price: u64,
pub with_public_sender: bool,
pub with_blob: bool,
pub disable_wasm64: bool,
pub disable_wasm32: bool,
pub disable_3rd_party: bool,
pub disable_phoenix: bool,
pub with_reference_types: bool,
pub phoenix_refund_check: bool,
pub deploy_remaining_gas_check: bool,
pub charge_init_gas: bool,
pub withdrawal_nullifier_check: bool,
}Expand description
Configuration for the execution of a transaction.
Fields
gas_per_deploy_byte: u64The amount of gas points charged for each byte in a contract-deployment bytecode.
gas_per_blob: u64The amount of gas points charged for each blob in a transaction.
min_deploy_points: u64The minimum gas points charged for a contract deployment.
min_deploy_gas_price: u64The minimum gas price set for a contract deployment
with_public_sender: boolEnable the public sender metadata in the transaction.
This field may be deprecated after the feature rollout.
with_blob: boolEnable the blob processing by the VM
disable_wasm64: boolDisable deployment of Wasm64 contracts
disable_wasm32: boolDisable deployment of Wasm32 contracts
disable_3rd_party: boolDisable calls to 3rd party contracts
disable_phoenix: boolDisable Phoenix transactions and Phoenix-related transfer functions.
with_reference_types: boolEnable WebAssembly reference-types in deployed contract bytecode.
phoenix_refund_check: boolEnforce phoenix fee refund stealth address matches change note
deploy_remaining_gas_check: boolEnforce the Boreas deploy gas rule that compares deploy charge against remaining gas only.
charge_init_gas: boolCharge gas consumed by the contract’s init function during
deployment.
withdrawal_nullifier_check: boolEnforce that Phoenix withdrawal replay tokens carry exactly the same number of nullifiers as the encapsulating transaction.
Implementations