[doc = include_str!(“../README.md”)]
Modules
- host_
queries - The host-queries registered on the Dusk VM
Structs
- Call
Receipt - The receipt given for a call execution using one of either
callorcall_raw. This receipt is also returned within a tuple when a Contract is deployed and itsinitmethod is executed. - Call
Tree - A cursor-based tree structure for tracking hierarchical contract calls.
- Call
Tree Elem - An element of the call tree, representing a single contract call.
- Contract
Data - Contract
Metadata - Contract Metadata
- Execution
Config - Configuration for the execution of a transaction.
- Page
Opening - A Merkle opening for page in the state.
- Session
- A running mutation to a state.
- VM
- The Virtual Machine (VM) for executing smart contracts in the Dusk Network.
Enums
- Error
- The error type returned by the piecrust VM.
- Execution
Error - Errors that can occur during transaction execution in the VM.
- Feature
Activation - Represents the activation condition for a feature or host query.
Functions
- execute
- Executes a transaction in the provided session.
- gen_
contract_ id - Generates the canonical identifier of a contract deployment.